# sample_one.py

import wx

# class MyStaticText
# class MyFrame
# class MyApp

#---------------------------------------------------------------------------

class MyStaticText(wx.Window):
    """
    Thanks to Alain Delgrange.
    """
    def __init__(self, parent, label):
        wx.Window.__init__(self, parent, -1)

        #------------

        # Attributes.
        self.parent = parent
        self.label = label

        #------------

        # Simplified init method.
        self.SetBackground()
        self.SetProperties()
        self.BindEvents()

    #-----------------------------------------------------------------------

    def SetBackground(self):
        """
        ...
        """

        self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)


    def SetProperties(self):
        """
        Set the properties.
        """
      
        self.police = wx.Font(18, wx.MODERN, wx.NORMAL, wx.BOLD, False, "Tahoma")

        width, height = self.GetFullTextExtent(self.label, font=self.police)[0:2]
        self.SetSize((width, height))


    def BindEvents(self):
        """
        Bind all the events related to my dialog.
        """

        # Bind a event to an events handler.
        self.Bind(wx.EVT_PAINT, self.OnPaint)


    def OnPaint(self, event):
        """
        ...
        """

        x, y = self.GetPosition()
        
        # Thank you Robin !
        dc = wx.BufferedPaintDC(self)
        l, h = dc.GetFullTextExtent(self.label, font=self.police)[0:2]
        dc.SetFont(wx.Font(18, wx.MODERN, wx.NORMAL, wx.BOLD, False, "Tahoma")) 
        self.SetSize((l, h))
        dc.Blit(0, 0, l, h, dc, x, y)
        dc.SetTextBackground(wx.NullColour)
        dc.SetTextForeground(wx.WHITE)
        dc.DrawText(self.label, 0, 0)

#---------------------------------------------------------------------------

class MyFrame(wx.Frame):
    """
    Thanks to Alain Delgrange.
    """
    def __init__(self):
        style = (wx.DEFAULT_FRAME_STYLE)
        wx.Frame.__init__(self,
                          None,
                          -1,
                          title="",
                          size=(380, 130),
                          style=style)

        #------------

        # Simplified init method.
        self.SetProperties()
        self.CreateCtrls()
        self.BindEvents()

    #-----------------------------------------------------------------------

    def SetProperties(self):
        """
        Set the frame properties (title, icon...).
        """

        self.SetTitle("Text with transparent background - 1")

        #------------

        frameicon = wx.Icon("Icons/wxWidgets.ico")
        self.SetIcon(frameicon)
        

    def CreateCtrls(self):
        """
        Make widgets for my frame.
        """

        self.pnl = wx.Panel(self,
                            -1,
                            size=self.GetClientSize(),
                            style=wx.TAB_TRAVERSAL |
                                  wx.CLIP_CHILDREN)
        self.pnl.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)

        self.staticTxt = MyStaticText(self.pnl, "Hello world !")
        self.staticTxt.CentreOnParent()


    def BindEvents(self):
        """
        Bind all the events related to my frame.
        """

        # Bind some events to an events handler.
        self.Bind(wx.EVT_SIZE, self.OnResize)
        self.pnl.Bind(wx.EVT_PAINT, self.OnPaint)


    def OnResize(self, event):
        """
        ...
        """

        self.pnl.SetSize(self.GetClientSize())
        self.pnl.Refresh()
        self.staticTxt.CentreOnParent()


    def OnPaint(self, event=None):
        """
        ...
        """

        size = self.pnl.GetRect()

        dc = wx.BufferedPaintDC(self.pnl)
        dc.GradientFillLinear((0,
                               0,
                               int(size[2]/2),
                               int(size[3])),
                               wx.RED,
                               wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENU),
                               wx.WEST)

        dc.GradientFillLinear((int(size[2]/2),
                               0,
                               int(size[2]/2),
                               int(size[3])),
                               wx.RED,
                               wx.SystemSettings.GetColour(wx.SYS_COLOUR_MENU),
                               wx.EAST)

#---------------------------------------------------------------------------

class MyApp(wx.App):
    """
    ...
    """
    def OnInit(self):

        #------------

        frame = MyFrame()
        self.SetTopWindow(frame)
        frame.Show(True)

        return True

#---------------------------------------------------------------------------

def main():
    app = MyApp(False)
    app.MainLoop()

#---------------------------------------------------------------------------

if __name__ == "__main__" :
    main()
